tlslite.errors.TLSAuthorizationError

Package tlslite :: Module errors :: Class TLSAuthorizationError |
[show private | hide private]
[frames | no frames]

## Class TLSAuthorizationError

         Exception --+
                     |
              TLSError --+
                         |
    TLSAuthenticationError --+
                             |
                            TLSAuthorizationError

The Checker was expecting the other party to authenticate with a certificate chain that has a different authorization.

Method Summary
Inherited from Exception
| ``__init__`(...)`
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:53 2005 | http://epydoc.sf.net